import { jsx } from 'theme-ui';
import PropTypes from 'prop-types';
import { PANEL_SIZES, LAYOUT_PROP_TYPES } from './../constants';
const NAV_WIDTH = '6em';
const CONTENT_MIN_WIDTH = '60em';
const sizeInCSSUnits = (theme, size) => {
    switch (size) {
        case 'sidebar':
            return '10em';
        case 'aside':
            return '20em';
        default:
            return `calc(100vw - ${theme.space[2] * 3}px - ${NAV_WIDTH})`;
    }
};
const Card = ({ children, size, transparent = false, innerSx }) => (jsx("div", { sx: {
        display: 'grid',
        backgroundColor: !transparent && 'cardBackground',
        boxShadow: !transparent && 'card',
        minWidth: size && (theme => sizeInCSSUnits(theme, size)),
        gridTemplate: '100% / 100%',
        ...innerSx,
    } }, children));
Card.propTypes = {
    transparent: PropTypes.bool,
    size: PropTypes.oneOf(PANEL_SIZES),
    innerSx: PropTypes.object,
};
const gridBase = {
    display: 'grid',
    gridAutoFlow: 'column',
    gridAutoColumns: '1fr',
    gridAutoRows: '100%',
    gap: 3,
};
const Layout = ({ nav, navPanels, explorer }) => {
    const hasNavPanels = navPanels && navPanels.length > 0;
    return (jsx("main", { sx: {
            ...gridBase,
            padding: 3,
            gridTemplate: hasNavPanels
                ? `'nav panels explorer' 100% / ${NAV_WIDTH} min-content minmax(${CONTENT_MIN_WIDTH}, 1fr)`
                : `'nav explorer' 100% / ${NAV_WIDTH} minmax(${CONTENT_MIN_WIDTH}, 1fr)`,
            height: '100vh',
        } },
        nav && (jsx(Card, { innerSx: { gridArea: 'nav' }, transparent: true }, nav)),
        hasNavPanels && (jsx("div", { sx: {
                gridArea: 'panels',
                ...gridBase,
            } }, navPanels.map(({ component, key, size }) => (jsx(Card, { key: key, size: size }, component))))),
        explorer && (jsx("div", { sx: {
                ...gridBase,
                gridArea: 'explorer',
                gridAutoRows: '1fr',
                gridTemplateAreas: `'input response' 'console console'`,
            } },
            jsx(Card, null, explorer.input),
            jsx(Card, null, explorer.response),
            jsx(Card, { innerSx: { gridArea: 'console' } }, explorer.console)))));
};
Layout.propTypes = LAYOUT_PROP_TYPES;
export default Layout;
//# sourceMappingURL=Layout.js.map